pub struct CharPos(pub usize);Expand description
A character offset.
Because of multibyte UTF-8 characters,
a byte offset is not equivalent to a character offset.
The [SourceMap] will convert BytePos values to CharPos values as necessary.
Tuple Fields
0: usizeTrait Implementations
sourceimpl Ord for CharPos
impl Ord for CharPos
sourceimpl PartialEq<CharPos> for CharPos
impl PartialEq<CharPos> for CharPos
sourceimpl PartialOrd<CharPos> for CharPos
impl PartialOrd<CharPos> for CharPos
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for CharPos
impl Eq for CharPos
impl StructuralEq for CharPos
impl StructuralPartialEq for CharPos