Struct leo_span::span::Span

source ·
pub struct Span {
    pub lo: BytePos,
    pub hi: BytePos,
}
The span type which tracks where formatted errors originate from in a Leo file. This is used in many spots throughout the rest of the Leo crates.

Fields

lo: BytePos

The start (low) position of the span, inclusive.

hi: BytePos

The end (high) position of the span, exclusive. The length of the span is hi - lo.

Implementations

source

impl Span

source

pub fn new(start: BytePos, end: BytePos) -> Self

Generate a new span from the starting and ending positions.

source

pub const fn dummy() -> Self

Generates a dummy span with all defaults. Should only be used in temporary situations.

source

pub fn is_dummy(&self) -> bool

Is the span a dummy?