Span

Struct Span 

pub struct Span {
    pub lo: u32,
    pub hi: u32,
}
The span type which tracks where formatted errors originate from in a Leo file. This is used in many spots throughout the rest of the Leo crates.

Fields

lo: u32

The start (low) position of the span, inclusive.

hi: u32

The end (high) position of the span, exclusive. The length of the span is hi - lo.

Implementations

Source

impl Span

pub fn new(start: u32, end: u32) -> Self

Generate a new span from the starting and ending positions.

pub const fn dummy() -> Self

Generates a dummy span with all defaults. Should only be used in temporary situations.

pub fn is_dummy(&self) -> bool

Is the span a dummy?