Module leo_span::source_map
source · Structs
- File / Line / Column information on a
BytePos. - A single source in the
SourceMap. - The source map containing all recorded sources, methods to register new ones, and methods to query about spans in relation to recorded sources.
- Detailed information on a
Span.
Enums
- A file name.
Functions
- Is the env var
LEO_TESTFRAMEWORKnot enabled?