pub struct SourceMap { /* private fields */ }Expand description
The source map containing all recorded sources, methods to register new ones, and methods to query about spans in relation to recorded sources.
Implementations
Sourceimpl SourceMap
impl SourceMap
Sourcepub fn new_source(&self, source: &str, name: FileName) -> Rc<SourceFile>
pub fn new_source(&self, source: &str, name: FileName) -> Rc<SourceFile>
Registers source under the given file name, returning a SourceFile back.
Sourcepub fn find_source_file(&self, pos: u32) -> Option<Rc<SourceFile>>
pub fn find_source_file(&self, pos: u32) -> Option<Rc<SourceFile>>
Find the source file containing pos.
pub fn source_file_by_filename( &self, filename: &FileName, ) -> Option<Rc<SourceFile>>
Sourcepub fn contents_of_span(&self, span: Span) -> Option<String>
pub fn contents_of_span(&self, span: Span) -> Option<String>
Returns the source contents that is spanned by span.